<?php
/*
   EasyWebshop Delivery service example app
   Copyright (c) 2017 Jan Van Liedekerke

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

   Documentation: https://www.easywebshop.com/doc/api
*/

// Set variables, get all the data we need
define('APP_DEBUG', true); // Debug mode for testing, set to false in production

// Get the app settings
$settings = new SimpleXMLElement(file_get_contents(dirname(__FILE__) . '/settings.xml'));

// Get the data from the webshop
require 'easywebshop.php';
$appdata = easyApp();

/* This gives us the following array
Array
(
    [webshop] => Array
        (
            [email]	=> example@voorbeeldshop.be
            [url]	=> https://www.voorbeeldshop.be
            [name]	=> Voorbeeld webshop
            [country]	=> BE
            [lang]	=> nl
            [currency]	=> EUR
        )

    [response_time] => 0.00084
)

--------------------------------
	GET variables:
--------------------------------
Array
(
    [shop_id]		=> 544
    [webshop_url]	=> https://www.voorbeeldshop.be
    [firstname]		=> Test
    [lastname]		=> Customer
    [street]		=> Test street
    [no]		=> 1
    [zipcode]		=> 9000
    [city]		=> Gent
    [province]		=> (in most cases blank)
    [country]		=> BE
    [lang]		=> nl
    [weight]		=> 0 // total weight of the shopping basket, can be used to show/hide delivery methods or calculate prices
    [freeshipping]	=> 0 // discount condition
    [email]		=> customer@example.com
    [phone]		=> 0475123456
)*/

// Show all the data we have for testing
if (APP_DEBUG) {
	echo "<pre>--------------------------------\n\tGET variables:\n--------------------------------\n\n";
	print_r($_GET);
	echo "\n\n</pre>";
}

/*--------------------------------
	Delivery variables
		- These can be hard coded, or requested from another source
		- Prices can also depend on customer location, use $_GET['zipcode'] for this
-------------------------------*/

$delivery_prices = array(2.5, 1.5, 0);

/*--------------------------------
	Multilingual
-------------------------------*/

// Dutch
if ($_REQUEST['lang'] == 'nl') {
	$l_deliverymethod = 'Kies uw verzendmethode';
	$l_deliverymethods = array('Levering met drone', 'Levering met fiets', 'Afhalen in pakketautomaat');
	$l_confirm = 'Bevestigen';

// Other languages
} else {
	$l_deliverymethod = 'Choose your delivery method';
	$l_deliverymethods = array('Delivery by drone', 'Delivery by bicycle', 'Pick up in a packet machine');
	$l_confirm = 'Confirm';
}

/*--------------------------------
	Form submitted: process the data
-------------------------------*/

if (isset($_POST['deliverymethod'])) {

	// Send delivery method
	$ds_method = $l_deliverymethods[0];
	if (is_numeric($_POST['deliverymethod']) && isset($l_deliverymethods[$_POST['deliverymethod']])) {
		$ds_method = $l_deliverymethods[$_POST['deliverymethod']];
	}

	// Separate prices per delivery method
	$ds_price = $delivery_prices[0];
	if (is_numeric($_POST['deliverymethod']) && isset($delivery_prices[$_POST['deliverymethod']])) {
		$ds_price = $delivery_prices[$_POST['deliverymethod']];
	}

	// Show a logo on the confirm page, always use HTTPS for displaying images on a HTTPS page
	$ds_logo = 'https://www.easywebshop.be/img/logos/easywebshop-200-whitebg.png';

	// Order number
	$ds_info = 'Reference ' . rand(0, 10000); // this can be a reference to an external database

	// Confirm delivery method
	header('Location: ' . $appdata['webshop']['url'] . '/dsconfirm' .
		'?ds=' . urlencode($settings->name) .
		'&ds_price=' . $ds_price .
		'&ds_method=' . urlencode($ds_method) .
		'&ds_info=' . urlencode($ds_info) .
		'&ds_logo=' . urlencode($ds_logo));

	die;
}
/*--------------------------------
	Start HTML page
		- Let's keep it very simple
-------------------------------*/

// Header
echo '<!DOCTYPE html><html lang="en"><head><title>' . $settings->name . ' App</title><meta charset="utf-8">' .
	'<link rel="stylesheet" href="script/style.css"></head>' . // you can also include javascript here
	'<body><main><img src="im/easywebshop-200-whitebg.png" alt="EasyWebshop" id="logo"><h1>' . $settings->name . ' App</h1>' .

	// Form
	'<form method="POST">' .
	'<input type="hidden" name="shop_id" value="' . $_REQUEST['shop_id'] . '">' .
	'<input type="hidden" name="lang" value="' . $_REQUEST['lang'] . '">' .
	'<table>' .
	'<tr><td>' . $l_deliverymethod . '</td><td>';

// Loop delivery methods
foreach ($l_deliverymethods as $k => $v) {
	echo '<input type="radio" name="deliverymethod" value="' . $k . '"> ' . $v . ' <strong>€ ' . $delivery_prices[$k] . '</strong><br>';
}
echo '</td></tr>' .

	// Submit form
	'<tr><td></td><td><input type="submit" name="submit" value="' . $l_confirm . '"></td></tr>' .
	'</table></form>' .

	// End page
	'</main></body></html>';

?>
